@@ -19,7 +19,11 @@
 #'
 #' \donttest{if (interactive()) app}
 leafletOutput <- function(outputId, width = "100%", height = 400) {
-  htmlwidgets::shinyWidgetOutput(outputId, "leaflet", width, height, "leaflet")
+  htmltools::attachDependencies(
+    htmlwidgets::shinyWidgetOutput(outputId, "leaflet", width, height, "leaflet"),
+    leafletBindingDependencies(),
+    append = TRUE
+  )
 }
 
 # use expr description from htmlwidgets to avoid bad inherit params code
